@@ -1,18 +1,15 @@
 package Getopt::EX::Colormap;
-use version; our $VERSION = version->declare("v1.28.0_01");
+use version; our $VERSION = version->declare("v1.28.0_02");
 
 use v5.14;
-use warnings;
 use utf8;
 
 use Exporter 'import';
-our @EXPORT      = qw();
-our @EXPORT_OK   = qw(
-    colorize colorize24 ansi_code ansi_pair csi_code
-    colortable colortable6 colortable12 colortable24
+our @EXPORT_OK = (
+    qw( colorize colorize24 ansi_code ansi_pair csi_code ),
+    qw( colortable colortable6 colortable12 colortable24 ),
     );
-our %EXPORT_TAGS = (all => [ @EXPORT_OK ]);
-our @ISA         = qw(Getopt::EX::LabeledParam);
+our %EXPORT_TAGS = ( all => [ @EXPORT_OK ] );
 
 use Carp;
 use Data::Dumper;
@@ -20,12 +17,11 @@ $Data::Dumper::Sortkeys = 1;
 
 use List::Util qw(min max first);
 
-use Getopt::EX::LabeledParam;
+use parent 'Getopt::EX::LabeledParam';
 use Getopt::EX::Util;
 use Getopt::EX::Func qw(callable);
 
 use Term::ANSIColor::Concise qw(:all);
-use Term::ANSIColor::Concise::Table qw(:all);
 {
     no strict 'refs';
     *colorize   = \&ansi_color;
@@ -43,6 +39,18 @@ use Term::ANSIColor::Concise::Table qw(:all);
     }
 }
 
+#use Term::ANSIColor::Concise::Table qw(:all);
+sub AUTOLOAD {
+    my $sub = our $AUTOLOAD =~ s/.*:://r;
+    return if $sub eq 'DESTROY';
+    if ($sub =~ /^colortable(?:|6|12|24)$/) {
+	require Term::ANSIColor::Concise::Table
+	    and Term::ANSIColor::Concise::Table->import(':all');
+	goto &$sub;
+    }
+    die "Invalid call for $sub().\n";
+}
+
 our $NO_NO_COLOR //= $ENV{GETOPTEX_NO_NO_COLOR};
 our $NO_COLOR    //= !$NO_NO_COLOR && defined $ENV{NO_COLOR};
 our $RGB24       //= $ENV{COLORTERM}//'' eq 'truecolor' || $ENV{GETOPTEX_RGB24};
@@ -257,7 +265,7 @@ at the module for detail.
     
     use strict;
     use warnings;
-
+    
     my @opt_colormap;
     use Getopt::EX::Long;
     GetOptions("colormap|cm=s" => \@opt_colormap);
@@ -276,7 +284,7 @@ at the module for detail.
         );
     
     $handler->load_params(@opt_colormap);
-
+    
     for (0 .. $#colors) {
         print $handler->index_color($_, "COLOR $_"), "\n";
     }
@@ -430,8 +438,6 @@ L<Term::ANSIColor::Concise>
 
 L<https://en.wikipedia.org/wiki/ANSI_escape_code>
 
-L<Graphics::ColorNames::X>
-
 L<https://en.wikipedia.org/wiki/X11_color_names>
 
 L<https://no-color.org/>
